@@ -3,13 +3,13 @@ import pymysql
 import sqlparse
 from .packages import special
 from pymysql.constants import FIELD_TYPE
-from pymysql.converters import (convert_mysql_timestamp, convert_datetime,
+from pymysql.converters import (convert_datetime,
                                 convert_timedelta, convert_date, conversions,
                                 decoders)
 try:
     import paramiko
-except:
-    paramiko = False
+except ImportError:
+    from mycli.packages.paramiko_stub import paramiko
 
 _logger = logging.getLogger(__name__)
 
@@ -42,7 +42,7 @@ class SQLExecute(object):
 
     def __init__(self, database, user, password, host, port, socket, charset,
                  local_infile, ssl, ssh_user, ssh_host, ssh_port, ssh_password,
-                 ssh_key_filename):
+                 ssh_key_filename, init_command=None):
         self.dbname = database
         self.user = user
         self.password = password
@@ -59,12 +59,13 @@ class SQLExecute(object):
         self.ssh_port = ssh_port
         self.ssh_password = ssh_password
         self.ssh_key_filename = ssh_key_filename
+        self.init_command = init_command
         self.connect()
 
     def connect(self, database=None, user=None, password=None, host=None,
                 port=None, socket=None, charset=None, local_infile=None,
                 ssl=None, ssh_host=None, ssh_port=None, ssh_user=None,
-                ssh_password=None, ssh_key_filename=None):
+                ssh_password=None, ssh_key_filename=None, init_command=None):
         db = (database or self.dbname)
         user = (user or self.user)
         password = (password or self.password)
@@ -79,6 +80,7 @@ class SQLExecute(object):
         ssh_port = (ssh_port or self.ssh_port)
         ssh_password = (ssh_password or self.ssh_password)
         ssh_key_filename = (ssh_key_filename or self.ssh_key_filename)
+        init_command = (init_command or self.init_command)
         _logger.debug(
             'Connection DB Params: \n'
             '\tdatabase: %r'
@@ -93,13 +95,15 @@ class SQLExecute(object):
             '\tssh_host: %r'
             '\tssh_port: %r'
             '\tssh_password: %r'
-            '\tssh_key_filename: %r',
+            '\tssh_key_filename: %r'
+            '\tinit_command: %r',
             db, user, host, port, socket, charset, local_infile, ssl,
-            ssh_user, ssh_host, ssh_port, ssh_password, ssh_key_filename
+            ssh_user, ssh_host, ssh_port, ssh_password, ssh_key_filename,
+            init_command
         )
         conv = conversions.copy()
         conv.update({
-            FIELD_TYPE.TIMESTAMP: lambda obj: (convert_mysql_timestamp(obj) or obj),
+            FIELD_TYPE.TIMESTAMP: lambda obj: (convert_datetime(obj) or obj),
             FIELD_TYPE.DATETIME: lambda obj: (convert_datetime(obj) or obj),
             FIELD_TYPE.TIME: lambda obj: (convert_timedelta(obj) or obj),
             FIELD_TYPE.DATE: lambda obj: (convert_date(obj) or obj),
@@ -110,15 +114,19 @@ class SQLExecute(object):
         if ssh_host:
             defer_connect = True
 
+        client_flag = pymysql.constants.CLIENT.INTERACTIVE
+        if init_command and len(list(special.split_queries(init_command))) > 1:
+            client_flag |= pymysql.constants.CLIENT.MULTI_STATEMENTS
+
         conn = pymysql.connect(
             database=db, user=user, password=password, host=host, port=port,
             unix_socket=socket, use_unicode=True, charset=charset,
-            autocommit=True, client_flag=pymysql.constants.CLIENT.INTERACTIVE,
+            autocommit=True, client_flag=client_flag,
             local_infile=local_infile, conv=conv, ssl=ssl, program_name="mycli",
-            defer_connect=defer_connect
+            defer_connect=defer_connect, init_command=init_command
         )
 
-        if ssh_host and paramiko:
+        if ssh_host:
             client = paramiko.SSHClient()
             client.load_system_host_keys()
             client.set_missing_host_key_policy(paramiko.WarningPolicy())
@@ -146,6 +154,7 @@ class SQLExecute(object):
         self.socket = socket
         self.charset = charset
         self.ssl = ssl
+        self.init_command = init_command
         # retrieve connection id
         self.reset_connection_id()
 
@@ -191,7 +200,6 @@ class SQLExecute(object):
                     if not cur.nextset() or (not cur.rowcount and cur.description is None):
                         break
 
-
     def get_result(self, cursor):
         """Get the current result's data from the cursor."""
         title = headers = None
