@@ -1,11 +1,9 @@
-# -*- coding: utf-8 -*-
 """Steps for behavioral style tests are defined in this module.
 
 Each step is defined by the string decorating it. This string is used
 to call the step in "*.feature" file.
 
 """
-from __future__ import unicode_literals
 
 import pexpect
 
@@ -36,7 +34,15 @@ def step_db_connect_test(context):
     """Send connect to database."""
     db_name = context.conf['dbname']
     context.currentdb = db_name
-    context.cli.sendline('use {0}'.format(db_name))
+    context.cli.sendline('use {0};'.format(db_name))
+
+
+@when('we connect to quoted test database')
+def step_db_connect_quoted_tmp(context):
+    """Send connect to database."""
+    db_name = context.conf['dbname']
+    context.currentdb = db_name
+    context.cli.sendline('use `{0}`;'.format(db_name))
 
 
 @when('we connect to tmp database')
@@ -66,15 +72,13 @@ def step_see_prompt(context):
     user = context.conf['user']
     host = context.conf['host']
     dbname = context.currentdb
-    wrappers.expect_exact(context, '{0}@{1}:{2}> '.format(
-        user, host, dbname), timeout=5)
-    context.atprompt = True
+    wrappers.wait_prompt(context, '{0}@{1}:{2}> '.format(user, host, dbname))
 
 
 @then('we see help output')
 def step_see_help(context):
     for expected_line in context.fixture_data['help_commands.txt']:
-        wrappers.expect_exact(context, expected_line + '\r\n', timeout=1)
+        wrappers.expect_exact(context, expected_line, timeout=1)
 
 
 @then('we see database created')
@@ -98,10 +102,7 @@ def step_see_db_dropped_no_default(context):
     context.currentdb = None
 
     wrappers.expect_exact(context, 'Query OK, 0 rows affected', timeout=2)
-    wrappers.expect_exact(context, '{0}@{1}:{2}> '.format(
-        user, host, database), timeout=5)
-
-    context.atprompt = True
+    wrappers.wait_prompt(context, '{0}@{1}:{2}>'.format(user, host, database))
 
 
 @then('we see database connected')
