@@ -1,5 +1,3 @@
-# coding: utf-8
-from __future__ import unicode_literals
 import pytest
 from mock import patch
 from prompt_toolkit.completion import Completion
