@@ -82,7 +82,7 @@ def test_invalid_syntax(executor):
 
 @dbtest
 def test_invalid_column_name(executor):
-    with pytest.raises(pymysql.InternalError) as excinfo:
+    with pytest.raises(pymysql.err.OperationalError) as excinfo:
         run(executor, 'select invalid command')
     assert "Unknown column 'invalid' in 'field list'" in str(excinfo.value)
 
@@ -166,7 +166,7 @@ def test_favorite_query_expanded_output(executor):
     results = run(executor, "\\fs test-ae select * from test")
     assert_result_equal(results, status='Saved.')
 
-    results = run(executor, "\\f test-ae \G")
+    results = run(executor, "\\f test-ae \\G")
     assert is_expanded_output() is True
     assert_result_equal(results, title='> select * from test',
                         headers=['a'], rows=[('abc',)], auto_status=False)
